# `xed`

`xed` is a utility for performing basic text transformations. `xed` is modeled
after the popular command-line tool `sed`.

Example invocation:

```
$ echo "Hello, world!" | xed replace Hello Goodbye
Goodbye, world
```
